@@ -1,14 +1,15 @@
 import asyncio
+import inspect
+import pprint
 import sys
 import traceback
 from contextlib import asynccontextmanager
 from typing import Callable, Dict, Iterable, List, Optional, Set, Type, Union
 
-from graia.broadcast.builtin.derive import DeriveDispatcher
-from graia.broadcast.entities.dispatcher import BaseDispatcher
-
-from .builtin.event import ExceptionThrowed
+from .builtin.derive import DeriveDispatcher
+from .builtin.event import EventExceptionThrown
 from .entities.decorator import Decorator
+from .entities.dispatcher import BaseDispatcher
 from .entities.event import Dispatchable
 from .entities.exectarget import ExecTarget
 from .entities.listener import Listener
@@ -102,7 +103,9 @@ class Broadcast:
         event: Dispatchable,
         addition_dispatchers: Optional[List["T_Dispatcher"]] = None,
     ):
-        grouped: Dict[int, List[Listener]] = group_dict(listener_generator, lambda x: x.priorities.get(event.__class__) or x.priority)
+        grouped: Dict[int, List[Listener]] = group_dict(
+            listener_generator, lambda x: x.priorities.get(event.__class__) or x.priority
+        )
         event_dispatcher_mixin = dispatcher_mixin_handler(event.Dispatcher)
         if addition_dispatchers:
             event_dispatcher_mixin = event_dispatcher_mixin + addition_dispatchers
@@ -139,7 +142,7 @@ class Broadcast:
         if is_listener and target.namespace.disabled:  # type: ignore
             raise DisabledNamespace("caught a disabled namespace: {0}".format(target.namespace.name))  # type: ignore
 
-        target_callable = target.callable if is_exectarget else target  # type: ignore
+        target_callable: Callable = target.callable if is_exectarget else target  # type: ignore
         parameter_compile_result = {}
 
         dispatchers = [
@@ -188,16 +191,38 @@ class Broadcast:
             result = await run_always_await(target_callable, **parameter_compile_result)
         except (ExecutionStop, PropagationCancelled):
             raise
-        except RequirementCrashed:
-            traceback.print_exc()
+        except RequirementCrashed as e:
+            name, *_ = e.args
+            param = inspect.signature(target_callable).parameters[name]
+            code = target_callable.__code__
+            etype = type(
+                "RequirementCrashed",
+                (RequirementCrashed, SyntaxError),
+                {},
+            )
+            traceback.print_exception(
+                etype,
+                etype(
+                    f"Unable to lookup parameter ({param}) by dispatchers\n{pprint.pformat(dispatchers)}",
+                    (
+                        code.co_filename,
+                        code.co_firstlineno,
+                        1,
+                        str(param),
+                        code.co_firstlineno,
+                        len(name) + 1,
+                    ),
+                ),
+                e.__traceback__,
+            )
             raise
         except Exception as e:
             event: Optional[Dispatchable] = self.event_ctx.get()
-            if event is not None and event.__class__ is not ExceptionThrowed:
+            if event is not None and event.__class__ is not EventExceptionThrown:
                 if print_exception:
                     traceback.print_exc()
                 if post_exception_event:
-                    self.postEvent(ExceptionThrowed(exception=e, event=event))
+                    self.postEvent(EventExceptionThrown(exception=e, event=event))
             raise
         finally:
             _, exception, tb = sys.exc_info()
@@ -209,7 +234,7 @@ class Broadcast:
             dii.ctx.reset(dii_token)
 
         if result.__class__ is Force:
-            return result.content
+            return result.target
         elif result is RemoveMe:
             if is_listener and target in self.listeners:
                 self.listeners.remove(target)
@@ -243,11 +268,11 @@ class Broadcast:
             raise
         except Exception as e:
             event: Optional[Dispatchable] = self.event_ctx.get()
-            if event is not None and event.__class__ is not ExceptionThrowed:
+            if event is not None and event.__class__ is not EventExceptionThrown:
                 if print_exception:
                     traceback.print_exc()
                 if post_exception_event:
-                    self.postEvent(ExceptionThrowed(exception=e, event=event))
+                    self.postEvent(EventExceptionThrown(exception=e, event=event))
             raise
         finally:
             _, exception, tb = sys.exc_info()
@@ -353,7 +378,7 @@ class Broadcast:
             _name = event
             event = self.findEvent(event)  # type: ignore
             if not event:
-                raise InvalidEventName(_name + " is not valid!")  # type: ignore
+                raise InvalidEventName(f"{_name} is not valid!")
         priority = int(priority)
 
         def receiver_wrapper(callable_target):
