@@ -1,5 +1,5 @@
 import typing
-from typing import Any, Callable, Optional
+from typing import Any, Callable, Optional, Union
 
 from ..entities.decorator import Decorator
 from ..entities.exectarget import ExecTarget
@@ -22,7 +22,7 @@ class Depend(Decorator):
 
     async def target(self, interface: DecoratorInterface):
         if self.cache:
-            attempt = interface.local_storage.get(self.depend_callable)
+            attempt = interface.local_storage.get(self.depend_callable)  # type: ignore
             if attempt:
                 return Force(attempt)
         result = await interface.dispatcher_interface.broadcast.Executor(
@@ -31,7 +31,7 @@ class Depend(Decorator):
         )
 
         if self.cache:
-            interface.local_storage[self.depend_callable] = result
+            interface.local_storage[self.depend_callable] = result  # type: ignore
         return Force(result)
 
 
@@ -42,12 +42,15 @@ class OptionalParam(Decorator):
         self.origin = origin
 
     async def target(self, interface: DecoratorInterface) -> Optional[Any]:
+        annotation = interface.annotation
+        if typing.get_origin(annotation) is Union:
+            annotation = Union[tuple(x for x in typing.get_args(annotation) if x not in (None, type(None)))]  # type: ignore
         try:
             return Force(
-                await interface.dispatcher_interface.lookup_param(
+                await interface.dispatcher_interface.lookup_by_directly(
+                    interface,
                     interface.dispatcher_interface.name,
-                    typing.get_origin(interface.dispatcher_interface.annotation)
-                    or interface.dispatcher_interface.annotation,
+                    annotation,
                     self.origin,
                 )
             )
