@@ -20,7 +20,10 @@ class Force(ObjectContainer):
     """
 
 
-class RemoveMe(ObjectContainer):
+class RemoveMe:
     """当本标识的实例为一受 Executor 影响的 Listener 返回值时,
     Executor 会尝试在当前 Broadcast 实例中找出并删除本 Listener 实例.
     """
+
+    def __new__(cls):
+        return RemoveMe
